#!/bin/bash
#
# Tool to retrieve information needed for issuing an SAMG release 2016
# license for this Linux rsp. Mac machine.
#
# Base: FLEXlm V11.14.0
#
debuglevel=0
# ack && output handling: cautious
#debuglevel=1   

msg=""
err=0
exitcode=0

fallback=""

outfile="FLEXlmMachineInfo.txt"

echo "+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++"
echo "+++ Tool to retrieve information needed for issuing either:"
echo "+++"
echo "+++ - a NODE LOCKED license for SAMG release 2016"
echo "+++   enabling run of SAMG applications on THIS Linux rsp. Mac machine"
echo "+++"
echo "+++ - or a FLOATING license for SAMG release 2016"
echo "+++   with THIS machine being [one of] the LICENSE SERVER[s],"
echo "+++   serving SAMG licenses for machines in [parts of] this IP network"
echo "+++   IMPORTANT:"
echo "+++   - ALL machines to be used for runs of SAMG applications MUST be"
echo "+++     IP-connected with this license server machine!"
echo "+++   - If you want a license for THREE-SERVER REDUNTANT license servers,"
echo "+++     please be sure to supply us with the respective information for"
echo "+++     each of the three machines."
echo "+++   - If you intended to run SAMG's license server combined with other"
echo "+++     license servers and several FlexNet hostids are listed for this"
echo "+++     machine, please point out which of them is used by the"
echo "+++     combined license server[s]."
echo "+++"
echo "+++   - ADDITIONALLY to the output below we need the [range of] IP-adresses"
echo "+++     of the machines supposed to run SAMG applications."
echo "+++"
echo "+++ ATTENTION:"
echo "+++ All Hardware Cards of this machine must be set up and activated in"
echo "+++ exactly the same way as they will be when running SAMG applications"
echo "+++ rsp. SAMG's license server daemon!"
echo "+++"
echo "+++ The information will be written into file ${outfile}"
echo ""
echo "+++ Press Ctrl-C to quit, any other key to continue."
read

if [ -e "$outfile" ] 
  then
    'rm' -f $outfile
    err=$?
    if test "$err" != "0" 
      then
        echo "+++ ERROR: Unable to remove file $outfile"
        echo "+++ $0 aborted"
        exit $err
    fi
fi

# os: Linux: Linux; Mac: Darwin
os=`uname`
arch=`uname -m`
osind="undef"
    
OK=0 
msg="Information not available for $os on $arch"
exitcode=999
    
if test "$debuglevel" != "0" 
   then 
      echo "os: $os; arch: $arch; osind: $osind"
fi

if test "$os" == "Linux"
  then
    osind="SomeLinux"
    msg="Sorry, SAMG is not available for $osind ($os on $arch) ..."
    if test "$debuglevel" != "0" 
      then 
        echo "Handling Linux: os: $os; arch: $arch; osind: $osind"
    fi
    for a in "i386" "i686"
    do
      if test "$a" = "$arch"
        then
        osind="Linux"
        msg="Sorry, SAMG release 2016 is not available for Linux 32bit"
	OK=0
	exitcode=9
      fi
    done
    if test "$arch" = "x86_64"
      then
        osind="LinuxX64"
#        fallback="Linux"
        msg="Information for $os on $arch"
        if test "$debuglevel" != "0" 
          then 
	    echo "OK: Linux: os: $os; arch: $arch; osind: $osind"
        fi
	OK=1
	exitcode=0
    fi
    if test "$arch" = "ia64"
      then
	osind="LinuxIA64"
	msg="Sorry, SAMG is not available for $osind"
	OK=0
        exitcode=9
    fi
  
  elif test "$os" == "Darwin"
    then
    osind="SomeMac"
    msg="Sorry, SAMG is not available for $osind ($os on $arch) ..."
    if test "$debuglevel" != "0" 
      then 
        echo "Handling Mac: os: $os; arch: $arch; osind: $osind"
    fi
    for a in "i386" "x86_64"
    do
      if test "$a" = "$arch"
        then
	  osind="Mac"
	  msg="Information for $os on $arch"
          if test "$debuglevel" != "0" 
            then 
	      echo "OK: Mac: os: $os; arch: $arch; osind: $osind"
          fi
	  OK=1
	  exitcode=0
      fi
    done
  else
    OK=0
    msg="This script can only be used on Linux or Mac, not on OS: $os"
    if test "$debuglevel" != "0" 
      then 
        echo "NOT OK: OS unknown: os: $os; arch: $arch; osind: $osind"
    fi
    exitcode=99
fi

if test "$OK" != "1"
  then
#    echo "Error occurred; Aborting"
    echo $msg
    exit $exitcode
fi

if test "$debuglevel" != "0" 
   then 
      echo "STARTING: os: $os; arch: $arch; osind: $osind"
fi
echo "SAMG license release 2016 request" > $outfile
echo "=================================" >> $outfile
echo "OS: $osind ($os $arch)"            >> $outfile
exitcode=0
$osind/lmutil lmhostid                   >> $outfile
exitcode=`expr $exitcode + $?`
$osind/lmutil lmhostid -internet         >> $outfile
exitcode=`expr $exitcode + $?`
$osind/lmutil lmhostid -hostname         >> $outfile
exitcode=`expr $exitcode + $?`

if test "$exitcode" != "0"
  then
    if test "$fallback" != ""
      then if test -d "$fallback"
        then
          exitcode=0
          $fallback/lmutil lmhostid               >> $outfile
          exitcode=`expr $exitcode + $?`
          $fallback/lmutil lmhostid -internet     >> $outfile
          exitcode=`expr $exitcode + $?`
          $fallback/lmutil lmhostid -hostname     >> $outfile
          exitcode=`expr $exitcode + $?`
          if test "$exitcode" != "0"
            then     
              echo "+++ ERROR: Problem at retrieving fallback MachineInfo. Exitcode: $exitcode" >> $outfile
              echo "Error occurred; Aborting"
              more  $outfile
              echo "+++ $0 aborted"
	      if test "$os" == "Linux"
	        then
		  echo "++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++"
                  echo "+++ If you encountered errormessages:"
                  echo "+++            command not found"
                  echo "+++ this machine probably is installed without the"
                  echo "+++    Linux Standard Base package ."
                  echo "+++ Please let your sysadmin install the package and try again."
                  echo "++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++"
	      fi
              exit $exitcode
	  fi
	else
          echo "+++ ERROR: Fallback MachineInfo not available. Exitcode: $exitcode" >> $outfile
          more $outfile
          echo "+++ $0 aborted"
          exit $exitcode  
        fi
    else
      echo "+++ ERROR: No fallback MachineInfo for this environment. Exitcode: $exitcode" >> $outfile
      more $outfile  
      echo "+++ $0 aborted"
      if test "$os" == "Linux"
	then
	  echo "++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++"
          echo "+++ If you encountered errormessages:"
          echo "+++            command not found"
          echo "+++ this machine probably is installed without the"
          echo "+++    Linux Standard Base package ."
          echo "+++ Please let your sysadmin install the package and try again."
          echo "++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++"
      fi
      exit $exitcode  
    fi
fi

echo ""
echo ""
echo "+++ Contents of file $outfile : "
echo ""
more  $outfile

echo ""
echo "++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++"
echo "+++ For requiring an SAMG release 2016 license please attach file"
echo "+++             ${outfile} "
echo "+++ to an email to:"
echo "+++                  samg@scapos.com "
echo "+++ "
echo "+++ This email should additionally contain the following information and data:"
echo "+++ - The name and full postal address of your company."
echo "+++ - The name and email address of the person to obtain the license."
echo "+++ "
echo "+++ - Whether you require a NODE LOCKED license or a FLOATING LICENSE plus,"
echo "+++   in case of a FLOATING LICENSE:"
echo "+++    - The range of IP addresses of the machines to be used for SAMG runs."
echo "+++    - If this machine is to be used in a license server triad:"
echo "+++      - The lmhostid of the other machines of that triad."
echo "+++      - If several hostids are listed for this machine: "
echo "+++        - Which of these hostids is to be used for the license server?"
echo "++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++"

exit $exitcode
